Build

Struct Build 

pub struct Build {
Show 13 fields pub branch: Option<String>, pub commit: Option<String>, pub created_at: DateTime<Utc>, pub error_code: Option<String>, pub error_message: Option<String>, pub finished_at: Option<DateTime<Utc>>, pub message: Option<String>, pub number: i64, pub pipeline_slug: String, pub scheduled_at: Option<DateTime<Utc>>, pub source: Option<String>, pub started_at: Option<DateTime<Utc>>, pub state: BuildState,
}
One run of a pipeline, identified by its pipeline-scoped number.

JSON schema
{
 "title": "Build",
 "description": "One run of a pipeline, identified by its
pipeline-scoped number.",
 "type": "object",
 "required": [
   "created_at",
   "number",
   "pipeline_slug",
   "state"
 ],
 "properties": {
   "branch": {
     "description": "Source branch.",
     "type": [
       "string",
       "null"
     ]
   },
   "commit": {
     "description": "Source commit SHA.",
     "type": [
       "string",
       "null"
     ]
   },
   "created_at": {
     "description": "When the build row was created.",
     "type": "string",
     "format": "date-time"
   },
   "error_code": {
     "description": "Stable build-level error code, if the build failed
at the build level.",
     "type": [
       "string",
       "null"
     ]
   },
   "error_message": {
     "description": "Human-readable build-level error message, if any.",
     "type": [
       "string",
       "null"
     ]
   },
   "finished_at": {
     "description": "When the build reached a terminal state.",
     "type": [
       "string",
       "null"
     ],
     "format": "date-time"
   },
   "message": {
     "description": "Commit/build message.",
     "type": [
       "string",
       "null"
     ]
   },
   "number": {
     "description": "The build's number, sequential and unique within
its pipeline.",
     "type": "integer"
   },
   "pipeline_slug": {
     "description": "The global slug of the pipeline this build belongs
to.",
     "type": "string"
   },
   "scheduled_at": {
     "description": "When the build was queued.",
     "type": [
       "string",
       "null"
     ],
     "format": "date-time"
   },
   "source": {
     "description": "How the build was triggered (e.g. `api`, `webhook`,
`ui`).",
     "type": [
       "string",
       "null"
     ]
   },
   "started_at": {
     "description": "When the build started running.",
     "type": [
       "string",
       "null"
     ],
     "format": "date-time"
   },
   "state": {
     "description": "The rolled-up build state.",
     "type": "string",
     "enum": [
       "scheduled",
       "running",
       "failing",
       "passed",
       "failed",
       "canceling",
       "canceled"
     ]
   }
 }
}

Fields

branch: Option<String>

Source branch.

commit: Option<String>

Source commit SHA.

created_at: DateTime<Utc>

When the build row was created.

error_code: Option<String>

Stable build-level error code, if the build failed at the build level.

error_message: Option<String>

Human-readable build-level error message, if any.

finished_at: Option<DateTime<Utc>>

When the build reached a terminal state.

message: Option<String>

Commit/build message.

number: i64

The build’s number, sequential and unique within its pipeline.

pipeline_slug: String

The global slug of the pipeline this build belongs to.

scheduled_at: Option<DateTime<Utc>>

When the build was queued.

source: Option<String>

How the build was triggered (e.g. api, webhook, ui).

started_at: Option<DateTime<Utc>>

When the build started running.

state: BuildState

The rolled-up build state.