pub struct Passkey {
pub aaguid: Option<String>,
pub created_at: DateTime<Utc>,
pub last_used_at: Option<DateTime<Utc>>,
pub nickname: Option<String>,
pub uuid: Uuid,
}Expand description
A WebAuthn credential registered to the current user.
JSON schema
{
"title": "Passkey",
"description": "A WebAuthn credential registered to the current user.",
"type": "object",
"required": [
"created_at",
"uuid"
],
"properties": {
"aaguid": {
"description": "The authenticator's AAGUID (model identifier), if
reported.",
"type": [
"string",
"null"
]
},
"created_at": {
"description": "When the passkey was registered.",
"type": "string",
"format": "date-time"
},
"last_used_at": {
"description": "When the passkey was last used to authenticate, if
ever.",
"type": [
"string",
"null"
],
"format": "date-time"
},
"nickname": {
"description": "Human label for the passkey.",
"type": [
"string",
"null"
]
},
"uuid": {
"description": "Stable passkey id.",
"type": "string",
"format": "uuid"
}
}
}Fields
aaguid: Option<String>The authenticator’s AAGUID (model identifier), if reported.
created_at: DateTime<Utc>When the passkey was registered.
last_used_at: Option<DateTime<Utc>>When the passkey was last used to authenticate, if ever.
nickname: Option<String>Human label for the passkey.
uuid: UuidStable passkey id.