RepoSummary

Struct RepoSummary 

pub struct RepoSummary {
    pub clone_url: Option<String>,
    pub default_branch: Option<String>,
    pub full_name: String,
    pub last_synced_at: Option<DateTime<Utc>>,
    pub name: String,
    pub owner: String,
    pub private: bool,
    pub registrations: Vec<RepoRegistration>,
}
A repository visible to the organization, identified by its canonical clone URL. One logical repository may be registered through several channels (e.g. the GitHub App and the CLI); each appears in registrations.

JSON schema
{
 "title": "RepoSummary",
 "description": "A repository visible to the organization, identified by
its canonical clone URL. One logical repository may be registered
through several channels (e.g. the GitHub App and the CLI); each appears
in `registrations`.",
 "type": "object",
 "required": [
   "full_name",
   "name",
   "owner",
   "private",
   "registrations"
 ],
 "properties": {
   "clone_url": {
     "description": "HTTPS clone URL (may be null for some providers).",
     "type": [
       "string",
       "null"
     ]
   },
   "default_branch": {
     "description": "Default branch name.",
     "type": [
       "string",
       "null"
     ]
   },
   "full_name": {
     "description": "`owner/name` full name.",
     "type": "string"
   },
   "last_synced_at": {
     "description": "Most recent sync across this repo's
registrations.",
     "type": [
       "string",
       "null"
     ],
     "format": "date-time"
   },
   "name": {
     "description": "Short repo name.",
     "type": "string"
   },
   "owner": {
     "description": "Owner/namespace login.",
     "type": "string"
   },
   "private": {
     "description": "Whether the repo is private.",
     "type": "boolean"
   },
   "registrations": {
     "description": "Every channel through which this repo is
registered.",
     "type": "array",
     "items": {
       "$ref": "#/components/schemas/RepoRegistration"
     }
   }
 }
}

Fields

clone_url: Option<String>

HTTPS clone URL (may be null for some providers).

default_branch: Option<String>

Default branch name.

full_name: String

owner/name full name.

last_synced_at: Option<DateTime<Utc>>

Most recent sync across this repo’s registrations.

name: String

Short repo name.

owner: String

Owner/namespace login.

private: bool

Whether the repo is private.

registrations: Vec<RepoRegistration>

Every channel through which this repo is registered.